@@ -1,9 +1,10 @@
 """
-# cascade.lines
+cascade.lines
+=============
 
 Contains dataset and model tracking lines
 
-Copyright 2022-2024 Ilia Moiseev
+Copyright 2022-2025 Ilia Moiseev
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
