@@ -1,7 +1,8 @@
 """
-# cascade.utils
+cascade.utils
+=============
 
-Copyright 2022-2024 Ilia Moiseev
+Copyright 2022-2025 Ilia Moiseev
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
